@@ -80,8 +80,8 @@ def clone(slug, version=None, fresh=True, include_outputs=True, overwrite=False)
     log('Fetching ' + slug + " " + ver_str + "..")
     gist = get_gist(slug, version, fresh)
     if not gist:
-        return 
-   
+        return
+
     title = gist['title']
 
     # If fresh clone, create directory
@@ -147,8 +147,11 @@ def pull(slug=None, version=None):
 
 
 def _sanitize_notebook(content):
-    # Delete  kernalspec entry
+    # Delete  kernelspec entry
     nb_content = json.loads(content.decode("utf-8"))
     if nb_content.get('metadata', {}).get('kernelspec'):
         del nb_content['metadata']['kernelspec']
-    return bytes(json.dumps(nb_content), 'utf-8')
+    try:
+        return bytes(json.dumps(nb_content), 'utf-8')
+    except TypeError:
+        return bytes(json.dumps(nb_content)).encode('utf-8')
